@@ -31,7 +31,7 @@ GeomRect <- ggproto("GeomRect", Geom,
 
   required_aes = c("xmin", "xmax", "ymin", "ymax"),
 
-  draw_panel = function(self, data, panel_scales, coord) {
+  draw_panel = function(self, data, panel_params, coord) {
     if (!coord$is_linear()) {
       aesthetics <- setdiff(
         names(data), c("x", "y", "xmin", "xmax", "ymin", "ymax")
@@ -42,12 +42,12 @@ GeomRect <- ggproto("GeomRect", Geom,
         aes <- as.data.frame(row[aesthetics],
           stringsAsFactors = FALSE)[rep(1,5), ]
 
-        GeomPolygon$draw_panel(cbind(poly, aes), panel_scales, coord)
+        GeomPolygon$draw_panel(cbind(poly, aes), panel_params, coord)
       })
 
       ggname("bar", do.call("grobTree", polys))
     } else {
-      coords <- coord$transform(data, panel_scales)
+      coords <- coord$transform(data, panel_params)
       ggname("geom_rect", rectGrob(
         coords$xmin, coords$ymax,
         width = coords$xmax - coords$xmin,
