@@ -1,6 +1,7 @@
 # Detect and prevent collisions.
 # Powers dodging, stacking and filling.
-collide <- function(data, width = NULL, name, strategy, ..., check.width = TRUE, reverse = FALSE) {
+collide_setup <- function(data, width = NULL, name, strategy,
+                          check.width = TRUE, reverse = FALSE) {
   # Determine width
   if (!is.null(width)) {
     # Width set manually
@@ -26,6 +27,15 @@ collide <- function(data, width = NULL, name, strategy, ..., check.width = TRUE,
     width <- widths[1]
   }
 
+  list(data = data, width = width)  
+}
+
+collide <- function(data, width = NULL, name, strategy,
+                    ..., check.width = TRUE, reverse = FALSE) {
+  dlist <- collide_setup(data, width, name, strategy, check.width, reverse)
+  data <- dlist$data
+  width <- dlist$width
+
   # Reorder by x position, then on group. The default stacking order reverses
   # the group in order to match the legend order.
   if (reverse) {
@@ -34,7 +44,6 @@ collide <- function(data, width = NULL, name, strategy, ..., check.width = TRUE,
     data <- data[order(data$xmin, -data$group), ]
   }
 
-
   # Check for overlap
   intervals <- as.numeric(t(unique(data[c("xmin", "xmax")])))
   intervals <- intervals[!is.na(intervals)]
@@ -44,7 +53,7 @@ collide <- function(data, width = NULL, name, strategy, ..., check.width = TRUE,
     # This is where the algorithm from [L. Wilkinson. Dot plots.
     # The American Statistician, 1999.] should be used
   }
-
+  
   if (!is.null(data$ymax)) {
     plyr::ddply(data, "xmin", strategy, ..., width = width)
   } else if (!is.null(data$y)) {
@@ -57,31 +66,22 @@ collide <- function(data, width = NULL, name, strategy, ..., check.width = TRUE,
   }
 }
 
+# Alternate version of collide() used by position_dodge2()
+collide2 <- function(data, width = NULL, name, strategy,
+                     ..., check.width = TRUE, reverse = FALSE) {
+  dlist <- collide_setup(data, width, name, strategy, check.width, reverse)
+  data <- dlist$data
+  width <- dlist$width
 
-# Dodge overlapping interval.
-# Assumes that each set has the same horizontal position.
-pos_dodge <- function(df, width) {
-  n <- length(unique(df$group))
-  if (n == 1) return(df)
-
-  if (!all(c("xmin", "xmax") %in% names(df))) {
-    df$xmin <- df$x
-    df$xmax <- df$x
+  # Reorder by x position, then on group. The default stacking order is
+  # different than for collide() because of the order in which pos_dodge2 places
+  # elements
+  if (reverse) {
+    data <- data[order(data$x, -data$group), ]
+  } else {
+    data <- data[order(data$x, data$group), ]
   }
 
-  d_width <- max(df$xmax - df$xmin)
-
-  # df <- data.frame(n = c(2:5, 10, 26), div = c(4, 3, 2.666666,  2.5, 2.2, 2.1))
-  # ggplot(df, aes(n, div)) + geom_point()
-
-  # Have a new group index from 1 to number of groups.
-  # This might be needed if the group numbers in this set don't include all of 1:n
-  groupidx <- match(df$group, sort(unique(df$group)))
-
-  # Find the center for each group, then use that to calculate xmin and xmax
-  df$x <- df$x + width * ((groupidx - 0.5) / n - .5)
-  df$xmin <- df$x - d_width / n / 2
-  df$xmax <- df$x + d_width / n / 2
-
-  df
+  pos <- match.fun(strategy)
+  pos(data, width, ...)
 }
