@@ -1,6 +1,13 @@
 #' @export
 #' @rdname geom_hex
 #' @inheritParams stat_bin_2d
+#' @section Computed variables:
+#' \describe{
+#'   \item{count}{number of points in bin}
+#'   \item{density}{density of points in bin, scaled to integrate to 1}
+#'   \item{ncount}{count, scaled to maximum of 1}
+#'   \item{ndensity}{density, scaled to maximum of 1}
+#' }
 stat_bin_hex <- function(mapping = NULL, data = NULL,
                          geom = "hex", position = "identity",
                          ...,
@@ -36,7 +43,7 @@ stat_binhex <- stat_bin_hex
 #' @usage NULL
 #' @export
 StatBinhex <- ggproto("StatBinhex", Stat,
-  default_aes = aes(weight = 1, fill = ..count..),
+  default_aes = aes(weight = 1, fill = stat(count)),
 
   required_aes = c("x", "y"),
 
@@ -48,7 +55,9 @@ StatBinhex <- ggproto("StatBinhex", Stat,
     wt <- data$weight %||% rep(1L, nrow(data))
     out <- hexBinSummarise(data$x, data$y, wt, binwidth, sum)
     out$density <- as.vector(out$value / sum(out$value, na.rm = TRUE))
+    out$ndensity <- out$density / max(out$density, na.rm = TRUE)
     out$count <- out$value
+    out$ncount <- out$count / max(out$count, na.rm = TRUE)
     out$value <- NULL
 
     out
