@@ -1,6 +1,6 @@
 context("Scales")
 
-test_that("buidling a plot does not affect its scales", {
+test_that("building a plot does not affect its scales", {
   dat <- data.frame(x = rnorm(20), y = rnorm(20))
 
   p <- ggplot(dat, aes(x, y)) + geom_point()
@@ -24,7 +24,6 @@ test_that("ranges update only for variables listed in aesthetics", {
 
   sc$train_df(data.frame())
   expect_equal(sc$range$range, c(1, 50))
-
 })
 
 test_that("mapping works", {
@@ -46,6 +45,7 @@ test_that("mapping works", {
 test_that("identity scale preserves input values", {
   df <- data.frame(x = 1:3, z = letters[1:3])
 
+  # aesthetic-specific scales
   p1 <- ggplot(df,
     aes(x, z, colour = z, fill = z, shape = z, size = x, alpha = x)) +
     geom_point() +
@@ -61,9 +61,19 @@ test_that("identity scale preserves input values", {
   expect_equal(d1$shape, as.character(df$z))
   expect_equal(d1$size, as.numeric(df$z))
   expect_equal(d1$alpha, as.numeric(df$z))
+
+  # generic scales
+  p2 <- ggplot(df,
+    aes(x, z, colour = z, fill = z, shape = z, size = x, alpha = x)) +
+    geom_point() +
+    scale_discrete_identity(aesthetics = c("colour", "fill", "shape")) +
+    scale_continuous_identity(aesthetics = c("size", "alpha"))
+  d2 <- layer_data(p2)
+
+  expect_equal(d1, d2)
 })
 
-test_that("position scales updated by all position aesthetics", {
+test_that("position scales are updated by all position aesthetics", {
   df <- data.frame(x = 1:3, y = 1:3)
 
   aesthetics <- list(
@@ -81,7 +91,6 @@ test_that("position scales updated by all position aesthetics", {
     expect_equal(range$x[[1]], c(1, 3))
     expect_equal(range$y[[1]], c(1, 3))
   })
-
 })
 
 test_that("position scales generate after stats", {
@@ -91,7 +100,6 @@ test_that("position scales generate after stats", {
 
   expect_equal(ranges$x[[1]], c("1"))
   expect_equal(ranges$y[[1]], c(0, 3))
-
 })
 
 test_that("oob affects position values", {
@@ -124,12 +132,10 @@ test_that("oob affects position values", {
   expect_equal(mid_censor[[1]]$y, c(0.5))
   expect_equal(low_squish[[1]]$y, c(0.2, 1, 1))
   expect_equal(mid_squish[[1]]$y, c(0, 0.5, 1))
-
-
 })
 
-test_that("scales looked for in appropriate place", {
-  xlabel <- function(x) ggplot_build(x)$layout$panel_scales$x[[1]]$name
+test_that("scales are looked for in appropriate place", {
+  xlabel <- function(x) ggplot_build(x)$layout$panel_scales_x[[1]]$name
   p0 <- qplot(mpg, wt, data = mtcars) + scale_x_continuous("0")
   expect_equal(xlabel(p0), "0")
 
@@ -168,7 +174,7 @@ test_that("find_global searches in the right places", {
     ggplot2::scale_colour_hue)
 })
 
-test_that("Scales warn when transforms introduces non-finite values", {
+test_that("scales warn when transforms introduces non-finite values", {
   df <- data.frame(x = c(1e1, 1e5), y = c(0, 100))
 
   p <- ggplot(df, aes(x, y)) +
@@ -178,7 +184,7 @@ test_that("Scales warn when transforms introduces non-finite values", {
   expect_warning(ggplot_build(p), "Transformation introduced infinite values")
 })
 
-test_that("Scales get their correct titles through layout", {
+test_that("scales get their correct titles through layout", {
   df <- data.frame(x = c(1e1, 1e5), y = c(0, 100))
 
   p <- ggplot(df, aes(x, y)) +
@@ -188,3 +194,85 @@ test_that("Scales get their correct titles through layout", {
   expect_identical(p$layout$xlabel(p$plot$labels)$primary, "x")
   expect_identical(p$layout$ylabel(p$plot$labels)$primary, "y")
 })
+
+test_that("size and alpha scales throw appropriate warnings for factors", {
+  df <- data.frame(
+    x = 1:3,
+    y = 1:3,
+    d = LETTERS[1:3],
+    o = factor(LETTERS[1:3], ordered = TRUE)
+  )
+  p <- ggplot(df, aes(x, y))
+
+  # There should be warnings when unordered factors are mapped to size/alpha
+  expect_warning(
+    ggplot_build(p + geom_point(aes(size = d))),
+    "Using size for a discrete variable is not advised."
+  )
+  expect_warning(
+    ggplot_build(p + geom_point(aes(alpha = d))),
+    "Using alpha for a discrete variable is not advised."
+  )
+  # There should be no warnings for ordered factors
+  expect_warning(ggplot_build(p + geom_point(aes(size = o))), NA)
+  expect_warning(ggplot_build(p + geom_point(aes(alpha = o))), NA)
+})
+
+test_that("shape scale throws appropriate warnings for factors", {
+  df <- data.frame(
+    x = 1:3,
+    y = 1:3,
+    d = LETTERS[1:3],
+    o = factor(LETTERS[1:3], ordered = TRUE)
+  )
+  p <- ggplot(df, aes(x, y))
+
+  # There should be no warnings when unordered factors are mapped to shape
+  expect_warning(ggplot_build(p + geom_point(aes(shape = d))), NA)
+
+  # There should be warnings for ordered factors
+  expect_warning(
+    ggplot_build(p + geom_point(aes(shape = o))),
+    "Using shapes for an ordinal variable is not advised"
+  )
+})
+
+test_that("aesthetics can be set independently of scale name", {
+  df <- data.frame(
+    x = LETTERS[1:3],
+    y = LETTERS[4:6]
+  )
+  p <- ggplot(df, aes(x, y, fill = y)) +
+    scale_colour_manual(values = c("red", "green", "blue"), aesthetics = "fill")
+
+  expect_equal(layer_data(p)$fill, c("red", "green", "blue"))
+})
+
+test_that("multiple aesthetics can be set with one function call", {
+  df <- data.frame(
+    x = LETTERS[1:3],
+    y = LETTERS[4:6]
+  )
+  p <- ggplot(df, aes(x, y, colour = x, fill = y)) +
+    scale_colour_manual(
+      values = c("grey20", "grey40", "grey60", "red", "green", "blue"),
+      aesthetics = c("colour", "fill")
+    )
+
+  expect_equal(layer_data(p)$colour, c("grey20", "grey40", "grey60"))
+  expect_equal(layer_data(p)$fill, c("red", "green", "blue"))
+
+  # color order is determined by data order, and breaks are combined where possible
+  df <- data.frame(
+    x = LETTERS[1:3],
+    y = LETTERS[2:4]
+  )
+  p <- ggplot(df, aes(x, y, colour = x, fill = y)) +
+    scale_colour_manual(
+      values = c("cyan", "red", "green", "blue"),
+      aesthetics = c("fill", "colour")
+    )
+
+  expect_equal(layer_data(p)$colour, c("cyan", "red", "green"))
+  expect_equal(layer_data(p)$fill, c("red", "green", "blue"))
+})
