@@ -1,4 +1,4 @@
-context("stat-hex")
+context("stat_hex")
 
 test_that("can use length 1 binwidth", {
   df <- data.frame(x = c(1, 1, 2), y = c(1, 1, 2))
